==> SCFiler2-0.09.zip: SCFiler2/SCFiler2/JumpFolderForm.designer.cs <==
﻿namespace SCFiler2 {
	partial class JumpFolderForm {
		/// <summary>
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary>
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary> 
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region Windows フォーム デザイナで生成されたコード

		/// <summary>
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.jump_folders_listview = new System.Windows.Forms.ListView();
			this.cancel_button = new System.Windows.Forms.Button();
			this.ok_button = new System.Windows.Forms.Button();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.del_button = new System.Windows.Forms.Button();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// jump_folders_listview
			// 
			this.jump_folders_listview.FullRowSelect = true;
			this.jump_folders_listview.LabelWrap = false;
			this.jump_folders_listview.Location = new System.Drawing.Point(12, 12);
			this.jump_folders_listview.MultiSelect = false;
			this.jump_folders_listview.Name = "jump_folders_listview";
			this.jump_folders_listview.Size = new System.Drawing.Size(443, 239);
			this.jump_folders_listview.TabIndex = 0;
			this.jump_folders_listview.UseCompatibleStateImageBehavior = false;
			this.jump_folders_listview.View = System.Windows.Forms.View.List;
			// 
			// cancel_button
			// 
			this.cancel_button.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancel_button.Location = new System.Drawing.Point(473, 197);
			this.cancel_button.Name = "cancel_button";
			this.cancel_button.Size = new System.Drawing.Size(99, 23);
			this.cancel_button.TabIndex = 1;
			this.cancel_button.Text = "キャンセル(&C)";
			this.cancel_button.UseVisualStyleBackColor = true;
			this.cancel_button.Click += new System.EventHandler(this.cancel_button_Click);
			// 
			// ok_button
			// 
			this.ok_button.Location = new System.Drawing.Point(473, 224);
			this.ok_button.Name = "ok_button";
			this.ok_button.Size = new System.Drawing.Size(99, 23);
			this.ok_button.TabIndex = 2;
			this.ok_button.Text = "OK(&O)";
			this.ok_button.UseVisualStyleBackColor = true;
			this.ok_button.Click += new System.EventHandler(this.ok_button_Click);
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.del_button);
			this.groupBox1.Location = new System.Drawing.Point(473, 12);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(93, 173);
			this.groupBox1.TabIndex = 3;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "選択アイテムを";
			// 
			// del_button
			// 
			this.del_button.Location = new System.Drawing.Point(6, 18);
			this.del_button.Name = "del_button";
			this.del_button.Size = new System.Drawing.Size(75, 23);
			this.del_button.TabIndex = 0;
			this.del_button.Text = "削除(&D)";
			this.del_button.UseVisualStyleBackColor = true;
			// 
			// JumpFolderForm
			// 
			this.AcceptButton = this.ok_button;
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.CancelButton = this.cancel_button;
			this.ClientSize = new System.Drawing.Size(578, 291);
			this.Controls.Add(this.groupBox1);
			this.Controls.Add(this.ok_button);
			this.Controls.Add(this.cancel_button);
			this.Controls.Add(this.jump_folders_listview);
			this.Name = "JumpFolderForm";
			this.Text = "ジャンプフォルダ";
			this.TopMost = true;
			this.Load += new System.EventHandler(this.JumpFolderForm_Load);
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}

		#endregion

		private System.Windows.Forms.ListView jump_folders_listview;
		private System.Windows.Forms.Button cancel_button;
		private System.Windows.Forms.Button ok_button;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button del_button;
	}
}

==> SCFiler2-0.14.zip: SCFiler2/SCFiler2/JumpFolderForm.designer.cs <==
﻿namespace SCFiler2 {
	partial class JumpFolderForm {
		/// <summary>
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary>
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary> 
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region Windows フォーム デザイナで生成されたコード

		/// <summary>
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.jump_folders_listview = new System.Windows.Forms.ListView();
			this.cancel_button = new System.Windows.Forms.Button();
			this.ok_button = new System.Windows.Forms.Button();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.del_button = new System.Windows.Forms.Button();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// jump_folders_listview
			// 
			this.jump_folders_listview.FullRowSelect = true;
			this.jump_folders_listview.LabelWrap = false;
			this.jump_folders_listview.Location = new System.Drawing.Point(12, 12);
			this.jump_folders_listview.MultiSelect = false;
			this.jump_folders_listview.Name = "jump_folders_listview";
			this.jump_folders_listview.Size = new System.Drawing.Size(443, 239);
			this.jump_folders_listview.TabIndex = 0;
			this.jump_folders_listview.UseCompatibleStateImageBehavior = false;
			this.jump_folders_listview.View = System.Windows.Forms.View.List;
			// 
			// cancel_button
			// 
			this.cancel_button.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancel_button.Location = new System.Drawing.Point(473, 197);
			this.cancel_button.Name = "cancel_button";
			this.cancel_button.Size = new System.Drawing.Size(99, 23);
			this.cancel_button.TabIndex = 1;
			this.cancel_button.Text = "キャンセル(&C)";
			this.cancel_button.UseVisualStyleBackColor = true;
			this.cancel_button.Click += new System.EventHandler(this.cancel_button_Click);
			// 
			// ok_button
			// 
			this.ok_button.Location = new System.Drawing.Point(473, 224);
			this.ok_button.Name = "ok_button";
			this.ok_button.Size = new System.Drawing.Size(99, 23);
			this.ok_button.TabIndex = 2;
			this.ok_button.Text = "OK(&O)";
			this.ok_button.UseVisualStyleBackColor = true;
			this.ok_button.Click += new System.EventHandler(this.ok_button_Click);
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.del_button);
			this.groupBox1.Location = new System.Drawing.Point(473, 12);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(93, 173);
			this.groupBox1.TabIndex = 3;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "選択アイテムを";
			// 
			// del_button
			// 
			this.del_button.Location = new System.Drawing.Point(6, 18);
			this.del_button.Name = "del_button";
			this.del_button.Size = new System.Drawing.Size(75, 23);
			this.del_button.TabIndex = 0;
			this.del_button.Text = "削除(&D)";
			this.del_button.UseVisualStyleBackColor = true;
			// 
			// JumpFolderForm
			// 
			this.AcceptButton = this.ok_button;
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.CancelButton = this.cancel_button;
			this.ClientSize = new System.Drawing.Size(578, 291);
			this.Controls.Add(this.groupBox1);
			this.Controls.Add(this.ok_button);
			this.Controls.Add(this.cancel_button);
			this.Controls.Add(this.jump_folders_listview);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Name = "JumpFolderForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "ジャンプフォルダ";
			this.TopMost = true;
			this.Load += new System.EventHandler(this.JumpFolderForm_Load);
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}

		#endregion

		private System.Windows.Forms.ListView jump_folders_listview;
		private System.Windows.Forms.Button cancel_button;
		private System.Windows.Forms.Button ok_button;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button del_button;
	}
}
